@@ -468,6 +468,12 @@ st_effect_t st_effects[] = {
         {"mcompand", ST_EFF_MCHAN,
                 st_mcompand_getopts, st_mcompand_start, st_mcompand_flow,
                 st_mcompand_drain, st_mcompand_stop},
+        {"noiseprof", ST_EFF_MCHAN | ST_EFF_REPORT,
+                st_noiseprof_getopts, st_noiseprof_start, st_noiseprof_flow,
+                st_noiseprof_drain, st_noiseprof_stop},
+        {"noisered", ST_EFF_MCHAN,
+                st_noisered_getopts, st_noisered_start, st_noisered_flow,
+                st_noisered_drain, st_noisered_stop},
         {"pan", ST_EFF_MCHAN | ST_EFF_CHAN,
                 st_pan_getopts, st_pan_start, st_pan_flow,
                 st_effect_nothing_drain, st_pan_stop},
